@@ -22,14 +22,14 @@ import java.security.PrivilegedActionException;
 import java.util.Arrays;
 import java.util.Set;
 
-import javax.servlet.Filter;
-import javax.servlet.FilterChain;
-import javax.servlet.Servlet;
-import javax.servlet.ServletException;
-import javax.servlet.ServletRequest;
-import javax.servlet.ServletResponse;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.Filter;
+import jakarta.servlet.FilterChain;
+import jakarta.servlet.Servlet;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.ServletRequest;
+import jakarta.servlet.ServletResponse;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 
 import org.apache.catalina.Globals;
 import org.apache.catalina.security.SecurityUtil;
@@ -37,7 +37,7 @@ import org.apache.tomcat.util.ExceptionUtils;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * Implementation of <code>javax.servlet.FilterChain</code> used to manage the execution of a set of filters for a
+ * Implementation of <code>jakarta.servlet.FilterChain</code> used to manage the execution of a set of filters for a
  * particular request. When the set of defined filters has all been executed, the next call to <code>doFilter()</code>
  * will execute the servlet's <code>service()</code> method itself.
  *
@@ -46,18 +46,9 @@ import org.apache.tomcat.util.res.StringManager;
 public final class ApplicationFilterChain implements FilterChain {
 
     // Used to enforce requirements of SRV.8.2 / SRV.14.2.5.1
-    private static final ThreadLocal<ServletRequest> lastServicedRequest;
-    private static final ThreadLocal<ServletResponse> lastServicedResponse;
+    private static final ThreadLocal<ServletRequest> lastServicedRequest = new ThreadLocal<>();
+    private static final ThreadLocal<ServletResponse> lastServicedResponse = new ThreadLocal<>();
 
-    static {
-        if (ApplicationDispatcher.WRAP_SAME_OBJECT) {
-            lastServicedRequest = new ThreadLocal<>();
-            lastServicedResponse = new ThreadLocal<>();
-        } else {
-            lastServicedRequest = null;
-            lastServicedResponse = null;
-        }
-    }
 
     // -------------------------------------------------------------- Constants
 
@@ -96,6 +87,11 @@ public final class ApplicationFilterChain implements FilterChain {
      */
     private boolean servletSupportsAsync = false;
 
+    /**
+     * Check the proper Servlet objects have been used.
+     */
+    private boolean dispatcherWrapsSameObject = false;
+
     /**
      * The string manager for our package.
      */
@@ -117,6 +113,16 @@ public final class ApplicationFilterChain implements FilterChain {
 
     // ---------------------------------------------------- FilterChain Methods
 
+    /**
+     * Invoke the next filter in this chain, passing the specified request and response. If there are no more filters in
+     * this chain, invoke the <code>service()</code> method of the servlet itself.
+     *
+     * @param request  The servlet request we are processing
+     * @param response The servlet response we are creating
+     *
+     * @exception IOException      if an input/output error occurs
+     * @exception ServletException if a servlet exception occurs
+     */
     @Override
     public void doFilter(ServletRequest request, ServletResponse response) throws IOException, ServletException {
 
@@ -154,7 +160,8 @@ public final class ApplicationFilterChain implements FilterChain {
             try {
                 Filter filter = filterConfig.getFilter();
 
-                if (request.isAsyncSupported() && !(filterConfig.getFilterDef().getAsyncSupportedBoolean())) {
+                if (request.isAsyncSupported() &&
+                        !(filterConfig.getFilterDef().getAsyncSupportedBoolean())) {
                     request.setAttribute(Globals.ASYNC_SUPPORTED_ATTR, Boolean.FALSE);
                 }
                 if (Globals.IS_SECURITY_ENABLED) {
@@ -169,17 +176,17 @@ public final class ApplicationFilterChain implements FilterChain {
                 }
             } catch (IOException | ServletException | RuntimeException e) {
                 throw e;
-            } catch (Throwable t) {
-                t = ExceptionUtils.unwrapInvocationTargetException(t);
-                ExceptionUtils.handleThrowable(t);
-                throw new ServletException(sm.getString("filterChain.filter"), t);
+            } catch (Throwable e) {
+                e = ExceptionUtils.unwrapInvocationTargetException(e);
+                ExceptionUtils.handleThrowable(e);
+                throw new ServletException(sm.getString("filterChain.filter"), e);
             }
             return;
         }
 
         // We fell off the end of the chain -- call the servlet instance
         try {
-            if (ApplicationDispatcher.WRAP_SAME_OBJECT) {
+            if (dispatcherWrapsSameObject) {
                 lastServicedRequest.set(request);
                 lastServicedResponse.set(response);
             }
@@ -200,12 +207,12 @@ public final class ApplicationFilterChain implements FilterChain {
             }
         } catch (IOException | ServletException | RuntimeException e) {
             throw e;
-        } catch (Throwable t) {
-            t = ExceptionUtils.unwrapInvocationTargetException(t);
-            ExceptionUtils.handleThrowable(t);
-            throw new ServletException(sm.getString("filterChain.servlet"), t);
+        } catch (Throwable e) {
+            e = ExceptionUtils.unwrapInvocationTargetException(e);
+            ExceptionUtils.handleThrowable(e);
+            throw new ServletException(sm.getString("filterChain.servlet"), e);
         } finally {
-            if (ApplicationDispatcher.WRAP_SAME_OBJECT) {
+            if (dispatcherWrapsSameObject) {
                 lastServicedRequest.set(null);
                 lastServicedResponse.set(null);
             }
@@ -268,6 +275,7 @@ public final class ApplicationFilterChain implements FilterChain {
         pos = 0;
         servlet = null;
         servletSupportsAsync = false;
+        dispatcherWrapsSameObject = false;
     }
 
 
@@ -294,6 +302,11 @@ public final class ApplicationFilterChain implements FilterChain {
     }
 
 
+    void setDispatcherWrapsSameObject(boolean dispatcherWrapsSameObject) {
+        this.dispatcherWrapsSameObject = dispatcherWrapsSameObject;
+    }
+
+
     /**
      * Identifies the Filters, if any, in this FilterChain that do not support async.
      *
